class PubSubTopics:
    # bits_v1 = 'channel-bits-events-v1.'
    bits = 'channel-bits-events-v2.'
    bits_badge_notification = 'channel-bits-badge-unlocks.'
    channel_points = 'channel-points-channel-v1.'
    channel_subscriptions = 'channel-subscribe-events-v1.'
    moderation_actions = 'chat_moderator_actions.'
    whispers = 'whispers.'
    community_channel_points = 'community-points-channel-v1.'
    twitch_poll_updates = 'polls.'
    follows = 'following.'
